ytmusicapi: Unofficial API for YouTube Music
==================================================
The purpose of this library is to automate interactions with `YouTube Music <https://music.youtube.com/>`_,
such as retrieving your library content, managing playlists and uploading songs.
To achieve this, it emulates web requests that would occur if you performed the same actions in your web browser.

**This project is not supported nor endorsed by Google**

.. include:: ../../README.rst
  :start-after: features
  :end-before: end-features

To **get started**, read the :doc:`setup instructions <setup/index>`.

For a **complete documentation** of available functions, see the :doc:`Reference <reference>`.

Contents
--------

.. toctree::
   :hidden:

   Home <self>

.. toctree::

   setup/index
   usage
   reference
   faq
